/*
 * Copyright (C) 2018, Matthias Clasen
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.0 of the
 * License.
 *
 * This file is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: LGPL-3.0-only
 */

#pragma once

#include <libportal/portal-enums.h>
#include <libportal/account.h>
#include <libportal/background.h>
#include <libportal/camera.h>
#include <libportal/dynamic-launcher.h>
#include <libportal/email.h>
#include <libportal/filechooser.h>
#include <libportal/inhibit.h>
#include <libportal/inputcapture.h>
#include <libportal/location.h>
#include <libportal/notification.h>
#include <libportal/openuri.h>
#include <libportal/parent.h>
#include <libportal/print.h>
#include <libportal/remote.h>
#include <libportal/screenshot.h>
#include <libportal/session.h>
#include <libportal/spawn.h>
#include <libportal/trash.h>
#include <libportal/types.h>
#include <libportal/updates.h>
#include <libportal/wallpaper.h>
